setClass("hg18track", 
	representation(name="character"), contains="eSet")

setClass("hg18track",       
         contains = "eSet",
         prototype = prototype(
           new("VersionedBiobase",
               versions=c(classVersion("eSet"), hg18track="1.0.0"))))


setMethod("initialize", "hg18track",
          function(.Object,
                   assayData = assayDataNew(
                     dataVals = dataVals, ...),
                   featureData = annotatedDataFrameFrom(assayData, byrow=TRUE),
                   experimentData = new("MIAME"),
                   annotation = character(),
                   dataVals = matrix(), 
                   ... ) {
			   callNextMethod(.Object,
                           assayData = assayData,
                           featureData = featureData,
                           experimentData = experimentData,
                           annotation = annotation)
          })

makeHg18track = function(dataVals, featureDataFrame, fvarMetadata = NULL, ... ) {
 if (length(dataVals) != nrow(featureDataFrame)) stop("dataVals vector length != nrow featureDataFrame")
 dv = matrix(dataVals, nc=1)
 rownames(featureDataFrame)  = rownames(dv) = 1:length(dataVals)
 if (is.null(fvarMetadata))
      adf = new("AnnotatedDataFrame", data=featureDataFrame)
 else adf = new("AnnotatedDataFrame", data=featureDataFrame, 
              varMetadata=fvarMetadata)
 new("hg18track", dataVals=dv, featureData=adf, ...)
}

setGeneric("dataVals", function(object)standardGeneric("dataVals"))
setMethod("dataVals", "hg18track", function(object) {
 get("dataVals", assayData(object))
})

setClass("chrnum", contains="numeric")
setGeneric("chrnum", function(x)standardGeneric("chrnum"))
setMethod("chrnum", "numeric", function(x)
  new("chrnum", x))
setMethod("chrnum", "hg18track", function(x) {
 cn = pData(featureData(x))$chrom
 if (any(cn == "chrX")) {
     cn[ cn == "chrX" ] = "chr23"
     if (options()$verbose) warning("chrX recoded to chr23")
     }
 as.numeric(gsub("chr", "", cn))
})


setMethod("[", "hg18track", function(x, i, j, ..., drop=FALSE) {
  if (!missing(j)) warning("sample indices ignored for hg18track")
  if (missing(i)) kpinds =   1:length(featureNames(x))
  else if (is(i, "chrnum")) kpinds =   which(chrnum(x) %in% i) 
  else if (is(i, "numeric")) kpinds = i
  else if (is(i, "logical")) kpinds = which(i)
  x@assayData = assayDataNew("lockedEnvironment",
        dataVals= matrix(dataVals(x)[ kpinds ], nc=1))
  x@featureData = featureData(x)[kpinds,]
  x
})

setGeneric("getTrkXY", function(object, type) standardGeneric("getTrkXY"))
setMethod("getTrkXY", c("hg18track", "character"), 
  function(object, type="midpoint") {
   Y = dataVals(object)
   Xs = pData(featureData(object))[,c("chromStart", "chromEnd")]
   X = apply(data.matrix(Xs),1,mean)
   list(x=X, y=Y)
})
setMethod("getTrkXY", c("hg18track", "missing"), 
  function(object, type="midpoint") {
    getTrkXY(object, "midpoint")
})

setGeneric("rangeLocs", function(object) standardGeneric("rangeLocs"))
setMethod("rangeLocs", "hg18track", function(object) {
 co = chrnum(object)
 if (!(all(co == co[1]))) stop("data on multiple chromosomes present; rangeLocs not meaningful")
 cs = pData(featureData(object))$chromStart
 ce = pData(featureData(object))$chromEnd
 an = as.numeric
 c(min(an(cs)), max(an(ce)))
})

setGeneric("chromStarts", function(x)standardGeneric("chromStarts"))
setMethod("chromStarts", "hg18track", function(x) {
 pData(featureData(x))[, "chromStart"]
})




juxtaPlot = function (trk, ssr, locstr)
{
    sy = -log10(p.value(ssr@.Data[[1]]))
    rsn = ssr@.Data[[1]]@snp.names
    names(sy) = rsn
    aloc = locstr["loc", ]
    locid = locstr["rsid", ]
    if (length(badl <- which(is.na(aloc))) > 0) {
        aloc = aloc[-badl]
        locid = locid[-badl]
    }
    names(aloc) = paste("rs", locid, sep = "")
    okid = intersect(names(aloc), rsn)
    aloc = aloc[okid]
    sy = sy[okid]
    sc = ssr@chrnum
    slab = paste("loc on chr", sc)
    txy = getTrkXY(trk)
    tgn = paste(ssr@gene, "-log10p")
    dfr = data.frame(y = sy, x = aloc, type = tgn)
    tmp = data.frame(y = as.numeric(txy$y), x = txy$x, type = "dnaseI")
    dfr = rbind(dfr, tmp)
    dfr$type = factor(dfr$type, levels = c("dnaseI", tgn))
    require(lattice)
    xyplot(y ~ x | type, data = dfr, layout = c(1, 2), xlab = slab,
        scales = list(relation = list(y = "free")))
}

