\name{hg18track-class}
\docType{class}
\alias{hg18track-class}
\alias{chrnum-class}
\alias{[,hg18track-method}
\alias{chrnum,numeric-method}
\alias{chrnum,hg18track-method}
\alias{chrnum}
\alias{rangeLocs}
\alias{chromStarts}
\alias{chromStarts,hg18track-method}
\alias{dataVals,hg18track-method}
\alias{rangeLocs,hg18track-method}
\alias{getTrkXY}
\alias{dataVals}
\alias{getTrkXY,hg18track,character-method}
\alias{getTrkXY,hg18track,missing-method}
\alias{initialize,hg18track-method}
\alias{demoTrk19}
\alias{clipTrk}
\alias{clipTrk,hg18track,numeric,numeric,ANY-method}
\alias{clipTrk,hg18track,numeric,numeric-method}
\alias{[,hg18track,ANY,ANY,ANY-method}
\alias{makeHg18track}

\title{Class "hg18track" container for hg18 annotation
 found in genome browser track files; class "chrnum" extends
numeric for an indexing application on hg18track objects. }
\description{container for hg18 annotation
 found in genome browser track files }
\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("hg18track", assayData, featureData, experimentData, annotation, dataVals, ...)}.
These are single-sample eSet instances.

Note that \code{demoTrk19} is a restriction of the \code{rawCD4} structure
to the interval of chromosome 19 that was assayed in the ENCODE project for DnaseI hypersensitivity.
}
\section{Slots}{
	 \describe{
    \item{\code{assayData}:}{Object of class \code{"AssayData"} ~~ }
    \item{\code{phenoData}:}{Object of class \code{"AnnotatedDataFrame"} ~~ }
    \item{\code{featureData}:}{Object of class \code{"AnnotatedDataFrame"} ~~ }
    \item{\code{experimentData}:}{Object of class \code{"MIAME"} ~~ }
    \item{\code{annotation}:}{Object of class \code{"character"} ~~ }
    \item{\code{.__classVersion__}:}{Object of class \code{"Versions"} ~~ }
  }
}
\section{Extends}{
Class \code{"\linkS4class{eSet}"}, directly.
Class \code{"\linkS4class{VersionedBiobase}"}, by class "eSet", distance 2.
Class \code{"\linkS4class{Versioned}"}, by class "eSet", distance 3.
}
\section{Methods}{
  \describe{
    \item{[}{\code{signature(x = "hg18track")}: select using
numeric, logical, or chrnum indices. }
    \item{chrnum}{\code{signature(object = "hg18track")}: extract
numeric tokens for chromosome number at which data values are
obtained; note that chrnum is also used as name of
a class.}
    \item{dataVals}{\code{signature(object = "hg18track")}: actual
data values }
    \item{getTrkXY}{\code{signature(object = "hg18track", type = "character")}: obtain a list with components x, y indicating location and
data value respectively; location is within chromosome; default type
is 'midpoint' of locations given as intervals }
    \item{getTrkXY}{\code{signature(object = "hg18track", type = "missing")}: 
take default midpoint x values corresponding to data values }
    \item{rangeLocs}{\code{signature(object = "hg18track")}: if measures from
only one chromosome are present , this returns low and high values of chromStart
and chromEnd respectively, otherwise error.}
    \item{clipTrk}{\code{signature(obj = "hg18track",
         low="numeric", hi="numeric", attr="ANY")}: create a restriction
         of the track using an interval specification.  by default
         the \code{chromStart} featureData component is used for
         coordinates to clip; if \code{attr} is non-missing, the
         featureData component named by \code{attr} will be used.}
    \item{initialize}{\code{signature(.Object = "hg18track")}: create
a new instance }
	 }
}
%\references{ ~put references to the literature/web site here ~ }
\author{ VJ Carey <stvjc@channing.harvard.edu> }
%\note{ ~~further notes~~ }
%
% ~Make other sections like Warning with \section{Warning }{....} ~
%
%\seealso{
%	~~objects to See Also as \code{\link{~~fun~~}}, ~~~
%	or \code{\linkS4class{CLASSNAME}} for links to other classes
%}
\examples{
showClass("hg18track")
data(rawCD4)
rawCD4
rawCD4.chr1 = rawCD4[ chrnum(1), ]
rangeLocs(rawCD4.chr1)
plot(getTrkXY(rawCD4.chr1), ylab="data value", xlab="interval midpt on chr 1" )
c52 = clipTrk(rawCD4[ chrnum(5), ], 1.30e8, 1.33e8 )
plot(getTrkXY(c52))
}
\keyword{classes}
